import React, { useState, useEffect, useMemo } from 'react'
import './index.less'
import { TreeSelect } from 'antd'
import { DownOutlined } from '@ant-design/icons'
import { getDeptList } from '../../../../apis/process'

const selectDept = ({ value, onChange, schema }) => {

  const { isMultiple, disabled, placeholder } = schema

  const [data, setData] = useState([])

  const valueShow = useMemo(() => {
    let valueShow = value || schema.default
    if (valueShow.includes('请求错误')) {
      return isMultiple ? '' : []
    }
    if (isMultiple) {
      return Array.isArray(valueShow) ? valueShow : (valueShow ? valueShow.split(',') : [])
    } else {
      return valueShow || null
    }
  }, [schema, value])

  const iconClick = async () => {
    let { code, data } = await getDeptList()
    if (code === 0) {
      setData(data)
    } else {
      onChange('请求错误')
    }
  }

  const onSelect = (value) => {
    if (isMultiple) {
      onChange(value.join(','));
    } else {
      onChange(value)
    }
  }

  const filterTreeNode = (inputValue, treeNode) => {
    if (treeNode.deptName.includes(inputValue)) {
      return true
    }
    return false
  }

  useEffect(() => {
    onChange(value || schema.default)
  }, [])

  return (
    <TreeSelect
      disabled={disabled}
      multiple={isMultiple}
      switcherIcon={<DownOutlined />}
      fieldNames={{ label: 'deptName', value: 'deptName', children: 'childDepts' }}
      treeData={data}
      onChange={onSelect}
      onFocus={iconClick}
      value={valueShow}
      filterTreeNode={filterTreeNode}
      showSearch
      showArrow={!disabled}
      allowClear
      treeDefaultExpandAll={true}
      placeholder={placeholder}
    >
    </TreeSelect>
  )

}

export default selectDept
